@@ -15,6 +15,7 @@ class BaseAPIView(APIView):
     def send_response(self, data=None, status=status.HTTP_200_OK):
         serializer = APIResponseSerializer({
             'success': True,
+            'status': status,
             'data': data
         })
         return Response(serializer.data, status=status)
@@ -22,6 +23,7 @@ class BaseAPIView(APIView):
     def send_error(self, error, status=status.HTTP_400_BAD_REQUEST):
         serializer = APIResponseSerializer({
             'success': False,
+            'status': status,
             'error': error
         })
         return Response(serializer.data, status=status)
@@ -32,7 +34,7 @@ class StandardAPIView(BaseAPIView):
 
     def paginate_data(self, data, request, serializer_class=None, context=None, **kwargs):
         # Create a paginator instance
-        paginator = self.pagination_class(**kwargs)
+        paginator = self.pagination_class(page_size=self.pagination_class.page_size, max_page_size=self.pagination_class.max_page_size)
 
         # Paginate the data object and return the paginated response
         paginated_data = paginator.paginate_data(data, request)
@@ -45,6 +47,7 @@ class StandardAPIView(BaseAPIView):
         response['count'] = paginator.count
         response['next'] = paginator.get_next_link()
         response['previous'] = paginator.get_previous_link()
+        response['status'] = status.HTTP_200_OK
 
         return response
 
@@ -78,13 +81,13 @@ class HelloWorldViewFakeData(BaseAPIView):
 class HelloWorldPaginatedView(StandardAPIView):
     def get(self, request, format=None):
         data = [
-        {'id': 1, 'content': 'Hello'},
-        {'id': 2, 'content': 'World'},
-        {'id': 3, 'content': 'This'},
-        {'id': 4, 'content': 'Is'},
-        {'id': 5, 'content': 'A'},
-        {'id': 6, 'content': 'Paginated'},
-        {'id': 7, 'content': 'Response'},
+            {'id': 1, 'content': 'Hello'},
+            {'id': 2, 'content': 'World'},
+            {'id': 3, 'content': 'This'},
+            {'id': 4, 'content': 'Is'},
+            {'id': 5, 'content': 'A'},
+            {'id': 6, 'content': 'Paginated'},
+            {'id': 7, 'content': 'Response'},
         ]
         if data:
             return self.paginate_data(data, request, page_size=3, max_page_size=5)
